@@ -1,5 +1,5 @@
 #------------------------------------------------------------------------------
-# Copyright (c) 2013-2017, Nucleic Development Team.
+# Copyright (c) 2013-2022, Nucleic Development Team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -23,6 +23,8 @@ from .xbms import (
     UNLINKED_BUTTON
 )
 
+from . import hover_event_pos
+
 
 class QDockWindowButtons(QFrame):
     """ A custom QFrame which provides the buttons for a QDockWindow.
@@ -430,7 +432,8 @@ class QDockWindow(QDockFrame):
         over the dock window buttons.
 
         """
-        if self._title_buttons.geometry().contains(event.pos()):
+        pos = hover_event_pos(event)
+        if self._title_buttons.geometry().contains(pos):
             self.unsetCursor()
         else:
             super(QDockWindow, self).hoverMoveEvent(event)
